@@ -1,6 +1,4 @@
 #
-# $Id: ODBCTEST.pm 15438 2012-10-08 21:07:54Z mjevans $
-#
 # Package ODBCTEST
 #
 # This package is a common set of routines for the DBD::ODBC tests.
@@ -49,6 +47,7 @@ require 5.004;
       my $type;
       my $type_info_all;
 
+      # yes, you can pass an array of types to type_info:
       $type_info = $dbh->type_info($TestFieldInfo{$column});
 
       if (!$type_info) {
@@ -93,7 +92,12 @@ require 5.004;
                    if ($row->{TYPE_NAME} eq 'VARCHAR') {
                        diag("This seems to be db2 and as far as I am aware, you cannot have a row greater than your page size. When I last looked db2 says a varchar can be 32672 but if we use that here the row will very likely be larger than your page size. Also, even if we reduce the varchar but keep it above 3962 db2 seems to complain so we mangle it here to 3962. It does not seem right to me that SQLGetTypeInfo says a varchar can be 32672 and then it is limited to 3962. If you know better, please let me know.");
                        $fields .= "(3962)";
-                  }
+                   }
+               } elsif (!exists($row->{COLUMN_SIZE})) {
+                   # Postgres 9 seems to omit COLUMN_SIZE
+                   $fields .= '(4000)';
+                   note("WARNING Your ODBC driver is broken - DBI's type_info method should return a hashref containing a key of COLUMN_SIZE and we got " .
+                            join(",", sort keys %$row));
                } else {
                    $fields .= "($row->{COLUMN_SIZE})" if ($row->{CREATE_PARAMS} =~ /LENGTH/i);
                    $fields .= "($row->{COLUMN_SIZE},0)" if ($row->{CREATE_PARAMS} =~ /PRECISION,SCALE/i);
@@ -124,8 +128,8 @@ require 5.004;
       $rc = -1;
 
       unless ($sth = $dbh->table_info()) {
-	 # diag("Can't list tables: $DBI::errstr\n");
-	 return -1;
+          diag("Can't list tables: $DBI::errstr\n");
+          return -1;
       }
 	# TABLE_QUALIFIER,TABLE_OWNER,TABLE_NAME,TABLE_TYPE,REMARKS
       while ($row = $sth->fetchrow_hashref()) {
